'use strict';

const Controller = require('egg').Controller;
// 车辆数量统计分析管理
class CarNumberController extends Controller {

  constructor(ctx) {
    super(ctx);
    // 特殊的入参校验可以重写在这，默认可以使用commonRule
    this.createRule = {
      startTime: { type: 'number', min: 0 }, // 开始时间的时间戳  包含
      endTime: { type: 'number', min: 0 }, // 结束时间的时间戳  不包含(客户端处理结束时间  下一日 ，下一月第一日 ，下一年第一日)
      type: [ '1', '2' ], // 类型分为   0日   1月   2年
    };
  }

  // 实销车辆统计分析 实销车辆百分比统计分析 入网车辆总数统计分析
  async index() {
    const { ctx, service } = this;
    // 校验参数 组装参数
    const payload = ctx.validate();

    // 调用 Service 进行业务处理
    const data = await service.tVehicleRecordService2.index(payload);
    // 设置响应内容和响应状态码
    ctx.success({ data });
  }

  // 实销车辆增量
  async increment() {
    const { ctx, service } = this;
    // 校验参数 组装参数
    const payload = ctx.validate();

    // 调用 Service 进行业务处理
    const data = await service.tVehicleRecordService2.increment(payload);
    // 设置响应内容和响应状态码
    ctx.success({ data });
  }

  // 在线车辆分布统计分析
  async online() {
    const { ctx, service } = this;
    // 校验参数 组装参数
    const payload = ctx.validate();

    // 调用 Service 进行业务处理
    const data = await service.tVehicleRecordService2.online(payload);
    // 设置响应内容和响应状态码
    ctx.success({ data });
  }

  // 活跃车辆
  async active() {
    const { ctx, service } = this;
    // 校验参数 组装参数
    const payload = ctx.validate(this.createRule);

    // 调用 Service 进行业务处理
    const data = await service.tVehicleRecordService2.active(payload);
    // 设置响应内容和响应状态码
    ctx.success({ data });
  }

  // 车辆上报分类信息统计
  async report() {
    const { ctx, service } = this;
    // 校验参数 组装参数
    const payload = ctx.validate();

    // 调用 Service 进行业务处理
    const data = await service.tVehicleReportInfoService.index(payload);
    // 设置响应内容和响应状态码
    ctx.success({ data });
  }


  // 在线数量
  async onlineCount() {
    const { ctx, service } = this;

    // 调用 Service 进行业务处理
    const data = await service.tVehicleOnlineInfoService.onlineCount();
    // 设置响应内容和响应状态码
    ctx.success({ data });
  }

  // 实销城市排名
  async saledCity() {
    const { ctx, service } = this;
    // 校验参数 组装参数
    const payload = ctx.validate({});

    // 调用 Service 进行业务处理
    const data = await service.tVehicleRecordService2.saledCity(payload);
    // 设置响应内容和响应状态码
    ctx.success({ data });
  }

  // 活跃额外
  async activeExt() {
    const { ctx, service } = this;
    // 校验参数 组装参数
    const payload = ctx.validate({});
    // 调用 Service 进行业务处理
    const data = await service.tVehicleRecordService2.activeExt(payload);
    // 设置响应内容和响应状态码
    ctx.success({ data });
  }


}

module.exports = CarNumberController;
