
'use strict';

const Service = require('egg').Service;

class IviBehaviorRecordService extends Service {

  async index({ type, startTime, endTime }) {
    const { ctx } = this;
    const agg = [
      { $match: ctx.helper.getTimeRangMatch(startTime, endTime) },
      { $group: ctx.helper.getTimeGroup(type, { total: { $sum: '$total' },
        musicTotal: { $sum: '$musicTotal' }, fwTotal: { $sum: '$fwTotal' },
        newsTotal: { $sum: '$newsTotal' }, videoTotal: { $sum: '$videoTotal' } }) },
    ];
    return await ctx.model.Local.IviBehaciorRecordModel.aggregateFix(agg);
  }

  async ext() {
    const { ctx } = this;
    const musicMonthAgg = [
      { $group: { _id: { year: '$year', month: '$month' }, count: { $sum: '$musicTotal' } } },
      { $sort: { count: -1 } },
    ];
    const musicYearAgg = [
      { $group: { _id: { year: '$year' }, count: { $sum: '$musicTotal' } } },
      { $sort: { count: -1 } },
    ];
    const musicMResult = await ctx.model.Local.IviBehaciorRecordModel.aggregateFix(musicMonthAgg);
    const musicYResult = await ctx.model.Local.IviBehaciorRecordModel.aggregateFix(musicYearAgg);
    let musicMaxMonth = {};
    let musicMinMonth = {};
    let musicMaxYear = {};
    let musicMinYear = {};
    if (musicMResult && musicMResult.length > 0) {
      musicMaxMonth = musicMResult[0];
      musicMinMonth = musicMResult[musicMResult.length - 1];
    }
    if (musicYResult && musicYResult.length > 0) {
      musicMaxYear = musicYResult[0];
      musicMinYear = musicYResult[musicYResult.length - 1];
    }

    const fwMonthAgg = [
      { $group: { _id: { year: '$year', month: '$month' }, count: { $sum: '$fwTotal' } } },
      { $sort: { count: -1 } },
    ];
    const fwYearAgg = [
      { $group: { _id: { year: '$year' }, count: { $sum: '$fwTotal' } } },
      { $sort: { count: -1 } },
    ];
    const fwMResult = await ctx.model.Local.IviBehaciorRecordModel.aggregateFix(fwMonthAgg);
    const fwYResult = await ctx.model.Local.IviBehaciorRecordModel.aggregateFix(fwYearAgg);
    let fwMaxMonth = {};
    let fwMinMonth = {};
    let fwMaxYear = {};
    let fwMinYear = {};
    if (fwMResult && fwMResult.length > 0) {
      fwMaxMonth = fwMResult[0];
      fwMinMonth = fwMResult[fwMResult.length - 1];
    }
    if (fwYResult && fwYResult.length > 0) {
      fwMaxYear = fwYResult[0];
      fwMinYear = fwYResult[fwYResult.length - 1];
    }

    const videoMonthAgg = [
      { $group: { _id: { year: '$year', month: '$month' }, count: { $sum: '$videoTotal' } } },
      { $sort: { count: -1 } },
    ];
    const videoYearAgg = [
      { $group: { _id: { year: '$year' }, count: { $sum: '$videoTotal' } } },
      { $sort: { count: -1 } },
    ];
    const videoMResult = await ctx.model.Local.IviBehaciorRecordModel.aggregateFix(videoMonthAgg);
    const videoYResult = await ctx.model.Local.IviBehaciorRecordModel.aggregateFix(videoYearAgg);
    let videoMaxMonth = {};
    let videoMinMonth = {};
    let videoMaxYear = {};
    let videoMinYear = {};
    if (videoMResult && videoMResult.length > 0) {
      videoMaxMonth = videoMResult[0];
      videoMinMonth = videoMResult[videoMResult.length - 1];
    }
    if (videoYResult && videoYResult.length > 0) {
      videoMaxYear = videoYResult[0];
      videoMinYear = videoYResult[videoYResult.length - 1];
    }

    return {
      musicMaxMonth, musicMinMonth, musicMaxYear, musicMinYear,
      fwMaxMonth, fwMinMonth, fwMaxYear, fwMinYear,
      videoMaxMonth, videoMinMonth, videoMaxYear, videoMinYear,
    };
  }


  // ====================清洗分割线==================================================================


  async statistics({ timeRangData, initData, isForceUpdate }) {
    const { ctx } = this;
    const hasData = await ctx.service.statisticsService.saveBefore(ctx.model.Local.IviBehaciorRecordModel,
      { ...initData });
    if (hasData && !isForceUpdate) {
      return;
    }
    initData.start_time = new Date();
    const obj = await this.total(timeRangData);
    ctx.logger.info('任务进行total');
    const total = obj.total || 0;

    const pageSize = 100;
    let pageNumber = 1;
    const taskCount = 100;
    const promiseArray = [];
    let promise = [];
    const iviBehavior = {
      musicTotal: 0,
      fwTotal: 0,
      newsTotal: 0,
      videoTotal: 0,
    };
    await ctx.model.TempModel.deleteMany();
    ctx.logger.info('任务进行deleteMany');
    const agg = [
      { $match: {
        ...ctx.helper.getTimeRangMatch(timeRangData.startTime, timeRangData.endTime, 'create_time'),
      } },
      { $out: 'temp' },
    ];
    await ctx.model.IviBehaviorRecordModel.aggregate(agg).allowDiskUse(true);
    ctx.logger.info('任务进行生成 当日行为临时表temp');
    do {
      promise.push(this.group(timeRangData, pageNumber, pageSize, iviBehavior));
      if (promise.length == taskCount){
        promiseArray.push(promise);
        promise = [];
      }
      pageNumber++;
    } while (pageNumber * pageSize < total);

    ctx.logger.info("任务数量"+pageNumber);
    ctx.logger.info("任务批次"+promiseArray.length);

    if (promiseArray != []) {
      for (let i = 0; i < promiseArray.length; i++) {
        await Promise.all(promiseArray[i]);
      }
    }

    ctx.logger.info("执行完成"+pageNumber);
   
    await ctx.service.statisticsService.save(ctx.model.Local.IviBehaciorRecordModel,
      { ...initData, ...iviBehavior, total }, isForceUpdate);
  }


  async total({ startTime, endTime }) {
    const { ctx } = this;
    const agg = [
      { $match: ctx.helper.getTimeRangMatch(startTime, endTime, 'start_time') },
      { $group: { _id: null,
        total: { $sum: { $toLong: '$mileage_cnt' } } } },
    ];
    return await ctx.model.DrivingBehaviorInfoModel.aggregateNGroup(agg);
  }

  async group({ startTime, endTime }, pageNumber, pageSize, iviBehavior) {
    const { ctx } = this;
    const agg = [
      { $match: { ...ctx.helper.getTimeRangMatch(startTime, endTime, 'start_time') } },
      { $unwind: '$mileage_list' },
      ...ctx.helper.getPageMongo(pageNumber, pageSize),
      { $lookup:
            {
              from: 'temp',
              let: { vin: '$vin', stime: '$mileage_list.start_time', etime: '$mileage_list.end_time' },
              pipeline: [{ $match: { $expr: { $and:
                        [
                          { $gte: [ '$create_time', '$$stime' ] },
                          { $lt: [ '$create_time', '$$etime' ] },
                          { $eq: [ '$vin', '$$vin' ] },
                        ] } } }], as: 'ivi',
            },
      },
      { $unwind: '$ivi' },
      { $group: {
        _id: '$mileage_list.start_time',
        behavior_id: { $addToSet: '$ivi.behavior_id' },
      } },
      { $unwind: '$behavior_id' },
      { $group: {
        _id: '$behavior_id',
        count: { $sum: 1 },
      } },
    ];
    const reulst = await ctx.model.DrivingBehaviorInfoModel.aggregateFix(agg);
    reulst.forEach(item => {
      switch (item._id) {
        case 20020001:
          iviBehavior.musicTotal += item.count;
          break;
        case 20010001:
          iviBehavior.fwTotal += item.count;
          break;
        case 20050001:
          iviBehavior.newsTotal += item.count;
          break;
        case 20030001:
          iviBehavior.videoTotal += item.count;
          break;
        default:
          break;
      }
    });
  }


}

module.exports = IviBehaviorRecordService;
