
'use strict';

const Service = require('egg').Service;

class OnlineUserService2 extends Service {

  // 在线日均总数 包含appTotal 和tBoxTotal
  async index({ type, startTime, endTime }) {
    const { ctx } = this;
    const agg = [
      { $match: ctx.helper.getTimeRangMatch(startTime, endTime) },
      { $group: ctx.helper.getTimeGroup(type, { total: { $avg: '$total' },
        appTotal: { $avg: '$appTotal' }, tBoxTotal: { $avg: '$tBoxTotal' },
      }) },
      { $project:
            {
              total: { $trunc: '$total' },
              appTotal: { $trunc: '$appTotal' },
              tBoxTotal: { $trunc: '$tBoxTotal' },
            },
      },

    ];
    return await ctx.model.Local.OnlineUserModel.aggregateFix(agg);
  }

  // 登录方式
  async mode({ type, startTime, endTime }) {
    const { ctx } = this;
    const agg = [
      { $match: ctx.helper.getTimeRangMatch(startTime, endTime) },
      { $group: ctx.helper.getTimeGroup(type, { faceTotal: { $sum: '$faceTotal' },
        voiceTotal: { $sum: '$voiceTotal' }, pwdTotal: { $sum: '$pwdTotal' },
        codeTotal: { $sum: '$codeTotal' }, scanTotal: { $sum: '$scanTotal' },
      }) },
    ];
    return await ctx.model.Local.OnlineUserModel.aggregateFix(agg);
  }

  // 登录渠道
  async channel({ type, startTime, endTime }) {
    const { ctx } = this;
    const agg = [
      { $match: ctx.helper.getTimeRangMatch(startTime, endTime) },
      { $group: ctx.helper.getTimeGroup(type, { appTotal: { $sum: '$appTotal' },
        iviTotal: { $sum: '$iviTotal' },
      }) },
    ];
    return await ctx.model.Local.OnlineUserModel.aggregateFix(agg);
  }

  // 登录角色
  async role({ type, startTime, endTime }) {
    const { ctx } = this;
    const agg = [
      { $match: ctx.helper.getTimeRangMatch(startTime, endTime) },
      { $group: ctx.helper.getTimeGroup(type, { carTotal: { $sum: '$carTotal' },
        commonTotal: { $sum: '$commonTotal' },
        guestTotal: { $sum: '$guestTotal' },
      }) },
    ];
    return await ctx.model.Local.OnlineUserModel.aggregateFix(agg);
  }

  // 登录状态
  async status({ type, startTime, endTime }) {
    const { ctx } = this;
    const agg = [
      { $match: ctx.helper.getTimeRangMatch(startTime, endTime) },
      { $group: ctx.helper.getTimeGroup(type, { successTotal: { $sum: '$successTotal' },
        failTotal: { $sum: '$failTotal' },
      }) },
    ];
    return await ctx.model.Local.OnlineUserModel.aggregateFix(agg);
  }

  async place(condStr, cond) {
    const { ctx } = this;
    const oneCond = { create_date: 1 };
    oneCond[condStr] = 1;
    let result;
    if (cond) {
      result = await ctx.model.Local.OnlineUserModel.findOne(
        { create_date: { $gte: cond.startTime, $lt: cond.endTime } }, oneCond)
        .sort({ create_date: -1 });
    } else {
      result = await ctx.model.Local.OnlineUserModel.findOne({}, oneCond)
        .sort({ create_date: -1 });
    }
    if (result) {
      return { time: ctx.helper.formatTime1(result.create_date), list: result[condStr] };
    }
    return { time: '', list: [] };
  }

  // app最高哪天  最低是哪天  当年总数    tbox最高哪天  最低是哪天  当年总数
  async ext() {
    const { ctx } = this;
    const appMax = await ctx.model.Local.OnlineUserModel.findOne().sort({ appTotal: -1 });
    const appMin = await ctx.model.Local.OnlineUserModel.findOne().sort({ appTotal: 1 });
    let maxApp = {};
    let minApp = {};
    if (appMax) {
      maxApp = { _id: { year: appMax.year, month: appMax.month, day: appMax.day }, count: appMax.appTotal };
    }
    if (appMin) {
      minApp = { _id: { year: appMin.year, month: appMin.month, day: appMin.day }, count: appMin.appTotal };
    }

    const tBoxMax = await ctx.model.Local.OnlineUserModel.findOne().sort({ tBoxTotal: -1 });
    const tBoxMin = await ctx.model.Local.OnlineUserModel.findOne().sort({ tBoxTotal: 1 });
    let maxTBox = {};
    let minTBox = {};
    if (tBoxMax) {
      maxTBox = { _id: { year: tBoxMax.year, month: tBoxMax.month, day: tBoxMax.day }, count: tBoxMax.tBoxTotal };
    }
    if (tBoxMin) {
      minTBox = { _id: { year: tBoxMin.year, month: tBoxMin.month, day: tBoxMin.day }, count: tBoxMin.tBoxTotal };
    }

    const maxMonthAgg = [
      { $group: { _id: { year: '$year', month: '$month' }, count: { $sum: '$total' } } },
      { $sort: { count: -1 } },
      { $group: { _id: null, data: { $first: '$$ROOT' } } },
      // 或者
      // { $group: { _id: null, data: { $max: { count: '$count', _id: { year: '$_id.year', month: '$_id.month' } } } } },
    ];
    const maxMonthResult = await ctx.model.Local.OnlineUserModel.aggregateNGroup(maxMonthAgg);
    const maxMonthTBox = maxMonthResult.data || {};

    const result = await ctx.model.Local.OnlineUserModel.findOne({}, { appYear: 1, tBoxYear: 1 })
      .sort({ create_date: -1 });
    let appYear = 0;
    let tBoxYear = 0;
    if (result) {
      appYear = result.appYear;
      tBoxYear = result.tBoxYear;
    }

    return { maxApp, minApp, maxTBox, minTBox, maxMonthTBox, appYear, tBoxYear };
  }

  // ---数据清洗----
  async statistics({ timeRangData, initData, isForceUpdate }) {
    const { ctx } = this;
    const hasData = await ctx.service.statisticsService.saveBefore(ctx.model.Local.OnlineUserModel,
      { ...initData });
    if (hasData && !isForceUpdate) {
      return;
    }
    initData.start_time = new Date();

    const { appTotal, iviTotal, tBoxTotal } = await this.count(timeRangData);
    const total = appTotal + tBoxTotal;
    ctx.logger.info('任务进行count');

    const { faceTotal, voiceTotal, pwdTotal, codeTotal, scanTotal } = await this.modeGroup(timeRangData);
    ctx.logger.info('任务进行modeGroup');

    const { carTotal, commonTotal, guestTotal } = await this.roleGroup(timeRangData);
    ctx.logger.info('任务进行roleGroup');

    let successTotal = 0;
    let failTotal = 0;
    const status = await this.statusGroup(timeRangData);
    status.forEach(item => {
      switch (item._id) {
        case 1:
          successTotal += item.count;
          break;
        case 2:
          failTotal += item.count;
          break;
        default:
          break;
      }
    });
    ctx.logger.info('任务进行statusGroup');

    const aResult = await this.appPlace(timeRangData);
    const appPlace = aResult.areas || [];
    ctx.logger.info('任务进行appPlace');

    const tResult = await this.tBoxPlace(timeRangData);
    const tBoxPlace = tResult.areas || [];
    ctx.logger.info('任务进行tBoxPlace');


    const al = await this.appLocation(timeRangData);
    const appLocation = al.areas || [];
    ctx.logger.info('任务进行appLocation');

    const anl = await this.appNewLocation(timeRangData);
    const appNewLocation = anl.areas || [];
    ctx.logger.info('任务进行appNewLocation');


    const aal = await this.appActiveLocation(timeRangData);
    const appActiveLocation = aal.areas || [];
    ctx.logger.info('任务进行appActiveLocation');

    const il = await this.iviLocation(timeRangData);
    const iviLocation = il.areas || [];
    ctx.logger.info('任务进行iviLocation');

    const inl = await this.iviNewLocation(timeRangData);
    const iviNewLocation = inl.areas || [];
    ctx.logger.info('任务进行iviNewLocation');

    const ial = await this.iviActiveLocation(timeRangData);
    const iviActiveLocation = ial.areas || [];
    ctx.logger.info('任务进行iviActiveLocation');

    const appYear = await this.getAppYearOnline(timeRangData);
    ctx.logger.info('任务进行getAppYearOnline');
    const tBoxYear = await this.getTboxYearOnline(timeRangData);
    ctx.logger.info('任务进行getTboxYearOnline');

    await ctx.service.statisticsService.save(ctx.model.Local.OnlineUserModel,
      { ...initData, total, appTotal, tBoxTotal, appPlace, tBoxPlace,
        appLocation, appNewLocation, appActiveLocation,
        iviLocation, iviNewLocation, iviActiveLocation,
        faceTotal, voiceTotal, pwdTotal, codeTotal, scanTotal,
        iviTotal, carTotal, commonTotal, guestTotal,
        successTotal, failTotal, appYear, tBoxYear,
      }, isForceUpdate);
  }

  async getAppYearOnline({ startTime }) {
    const { ctx } = this;
    const result = await ctx.model.AppOnlineUserModel.aggregateNGroup(
      [
        { $match: { login_time: { $gt: ctx.helper.nowYear(startTime) }, login_state: 1 } },
        { $group: { _id: '$user_Id' } },
        { $count: 'count' },
      ]
    );
    return result.count || 0;
  }

  async getTboxYearOnline({ startTime }) {
    const { ctx } = this;
    const result = await ctx.model.TBoxOnlineModel.aggregateNGroup(
      [
        { $match: { online_time: { $gt: ctx.helper.nowYear(startTime) } } },
        { $group: { _id: '$vin' } },
        { $count: 'count' },
      ]
    );
    return result.count || 0;
  }

  async count({ startTime, endTime }) {
    const { ctx } = this;
    const result = await ctx.model.IviOnlineUserModel.aggregateNGroup([
      { $match: { ...ctx.helper.getTimeRangMatch(startTime, endTime, 'login_time'), login_state: 1 } },
      { $group: {
        _id: '$user_id',
      } },
      { $count: 'count' },
    ]);
    const iviTotal = result.count || 0;

    const result2 = await ctx.model.AppOnlineUserModel.aggregateNGroup([
      { $match: { ...ctx.helper.getTimeRangMatch(startTime, endTime, 'login_time'), login_state: 1 } },
      { $group: {
        _id: '$user_Id',
      } },
      { $count: 'count' },
    ]);
    const appTotal = result2.count || 0;
    const result3 = await ctx.model.TBoxOnlineModel.aggregateNGroup([
      { $match: { ...ctx.helper.getTimeRangMatch(startTime, endTime, 'online_time') } },
      { $group: {
        _id: '$vin',
      } },
      { $count: 'count' },
    ]);
    const tBoxTotal = result3.count || 0;
    return { appTotal, tBoxTotal, iviTotal };
  }

  async modeGroup({ startTime, endTime }) {
    const { ctx } = this;
    const agg = [
      { $match: ctx.helper.getTimeRangMatch(startTime, endTime, 'login_time') },
      { $group: { _id: '$login_mode', count: { $sum: 1 } } },
    ];
    let faceTotal = 0;
    let voiceTotal = 0;
    let pwdTotal = 0;
    let codeTotal = 0;
    let scanTotal = 0;
    const aResult = await ctx.model.AppOnlineUserModel.aggregateFix(agg);
    aResult.forEach(item => {
      switch (item._id) { // 1：人脸、2：声纹、3：密码、4：验证码、5：二维码
        case 'FACE':
          faceTotal += item.count;
          break;
        case 'SOUND':
          voiceTotal += item.count;
          break;
        case 'PASSWORD':
          pwdTotal += item.count;
          break;
        case 'VERIFICATION_CODE':
          codeTotal += item.count;
          break;
        case 'QR':
          scanTotal += item.count;
          break;
        default:
          break;
      }
    });
    const iResult = await ctx.model.IviOnlineUserModel.aggregateFix(agg);
    iResult.forEach(item => {
      switch (item._id) { // 1：人脸、2：声纹、3：密码、4：验证码、5：二维码
        case 1:
          faceTotal += item.count;
          break;
        case 2:
          voiceTotal += item.count;
          break;
        case 3:
          pwdTotal += item.count;
          break;
        case 4:
          codeTotal += item.count;
          break;
        case 5:
          scanTotal += item.count;
          break;
        default:
          break;
      }
    });
    return { faceTotal, voiceTotal, pwdTotal, codeTotal, scanTotal };
  }

  async roleGroup({ startTime, endTime }) {
    const { ctx } = this;
    const agg = [
      { $match: ctx.helper.getTimeRangMatch(startTime, endTime, 'login_time') },
      { $group: { _id: '$role_id', count: { $sum: 1 } } },
    ];
    let carTotal = 0;
    let commonTotal = 0;
    let guestTotal = 0;
    const aResult = await ctx.model.AppOnlineUserModel.aggregateFix(agg);
    aResult.forEach(item => {
      switch (item._id) {
        case 'CAR_OWNER':
          carTotal += item.count;
          break;
        case 'user':
          commonTotal += item.count;
          break;
        case 'POTENTIAL':
          guestTotal += item.count;
          break;
        default:
          break;
      }
    });
    const iResult = await ctx.model.IviOnlineUserModel.aggregateFix(agg);
    iResult.forEach(item => { // owner 是车主，common是使用人，guest是潜客（粉丝）
      switch (item._id) {
        case 'owner':
          carTotal += item.count;
          break;
        case 'common':
          commonTotal += item.count;
          break;
        case 'guest':
          guestTotal += item.count;
          break;
        default:
          break;
      }
    });
    return { carTotal, commonTotal, guestTotal };
  }

  async statusGroup({ startTime, endTime }) {
    const { ctx } = this;
    const agg = [
      { $match: ctx.helper.getTimeRangMatch(startTime, endTime, 'login_time') },
      { $group: { _id: '$login_state', count: { $sum: 1 } } },
    ];
    const aResult = await ctx.model.AppOnlineUserModel.aggregateFix(agg);
    const iResult = await ctx.model.IviOnlineUserModel.aggregateFix(agg);
    return aResult.concat(iResult);
  }

  async appNewLocation({ startTime, endTime }) {
    const { ctx } = this;
    // const userArr = await ctx.model.TRbacUserModel.find({
    //   create_date: { $gte: ctx.helper.getMonthTop(startTime), $lt: endTime },
    //   user_orgin: 'APP' }, { user_id: 1, _id: 0 }).batchSize(100000);

    const agg = [
      { $match: { login_time: { $gte: ctx.helper.getMonthTop(startTime), $lt: endTime },
        // login_state: 1, user_Id: { $in: userArr.map(item => item.user_id) } } },
        login_state: 1 } },
      { $sort: { login_time: 1 } },
      { $group: { _id: '$user_Id',
        provice_name: { $first: '$provice_name' }, city_name: { $first: '$city_name' } } },
      { $lookup: { from: 't_sync_county', localField: 'provice_name', foreignField: 'province_name', as: 'area' } },
      { $project: {
        area_name: { $arrayElemAt: [ '$area.area_name', 0 ] },
        provice_name: 1,
        city_name: 1,
      } },
      { $addFields: {
        count: 1,
      } },
      { $match: { area_name: { $exists: true } } },
      ...ctx.helper.getLocationMongo(),
    ];
    return await ctx.model.AppOnlineUserModel.aggregateNGroup(agg);
  }
  async iviNewLocation({ startTime, endTime }) {
    const { ctx } = this;
    // const userArr = await ctx.model.TRbacUserModel.find({
    //   create_date: { $gte: ctx.helper.getMonthTop(startTime), $lt: endTime },
    //   user_orgin: 'IVI' }, { user_id: 1, _id: 0 }).batchSize(100000);

    const agg = [
      { $match: { login_time: { $gte: ctx.helper.getMonthTop(startTime), $lt: endTime },
        login_state: 1,
        // user_id: { $in: userArr.map(item => item.user_id) }
      } },
      { $sort: { login_time: 1 } },
      { $group: { _id: '$user_id',
        provice_name: { $first: '$provice_name' }, city_name: { $first: '$city_name' } } },
      { $lookup: { from: 't_sync_county', localField: 'provice_name', foreignField: 'province_name', as: 'area' } },
      { $project: {
        area_name: { $arrayElemAt: [ '$area.area_name', 0 ] },
        provice_name: 1,
        city_name: 1,
      } },
      { $addFields: {
        count: 1,
      } },
      { $match: { area_name: { $exists: true } } },
      ...ctx.helper.getLocationMongo(),
    ];
    return await ctx.model.IviOnlineUserModel.aggregateNGroup(agg);
  }
  async appActiveLocation({ startTime, endTime }) {
    const { ctx } = this;
    const agg = [
      { $match: { ...ctx.helper.getTimeRangMatch(startTime, endTime, 'login_time'), login_state: 1 } },
      { $sort: { login_time: 1 } },
      { $group: { _id: '$user_Id', provice_name: { $first: '$provice_name' }, city_name: { $first: '$city_name' } } },
      { $lookup: { from: 't_sync_county', localField: 'provice_name', foreignField: 'province_name', as: 'area' } },
      { $project: {
        area_name: { $arrayElemAt: [ '$area.area_name', 0 ] },
        provice_name: 1,
        city_name: 1,
      } },
      { $addFields: {
        count: 1,
      } },
      { $match: { area_name: { $exists: true } } },
      ...ctx.helper.getLocationMongo(),
    ];

    return await ctx.model.AppOnlineUserModel.aggregateNGroup(agg);
  }
  async iviActiveLocation({ startTime, endTime }) {
    const { ctx } = this;
    const agg = [
      { $match: { ...ctx.helper.getTimeRangMatch(startTime, endTime, 'login_time'), login_state: 1 } },
      { $sort: { login_time: 1 } },
      { $group: { _id: '$user_id', provice_name: { $first: '$provice_name' }, city_name: { $first: '$city_name' } } },
      { $lookup: { from: 't_sync_county', localField: 'provice_name', foreignField: 'province_name', as: 'area' } },
      { $project: {
        area_name: { $arrayElemAt: [ '$area.area_name', 0 ] },
        provice_name: 1,
        city_name: 1,
      } },
      { $addFields: {
        count: 1,
      } },
      { $match: { area_name: { $exists: true } } },
      ...ctx.helper.getLocationMongo(),
    ];
    return await ctx.model.IviOnlineUserModel.aggregateNGroup(agg);
  }
  async iviLocation({ endTime }) {
    const { ctx } = this;
    // const userArr = await ctx.model.TRbacUserModel.find({
    //   create_date: { $lt: endTime },
    //   user_orgin: 'IVI' }, { user_id: 1, _id: 0 }).batchSize(100000);

    const agg = [
      { $match: { login_time: { $lt: endTime }, login_state: 1,
        // user_id: { $in: userArr.map(item => item.user_id) }
      } },
      { $sort: { login_time: 1 } },
      { $group: { _id: '$user_id',
        provice_name: { $first: '$provice_name' }, city_name: { $first: '$city_name' } } },
      { $lookup: { from: 't_sync_county', localField: 'provice_name', foreignField: 'province_name', as: 'area' } },
      { $project: {
        area_name: { $arrayElemAt: [ '$area.area_name', 0 ] },
        provice_name: 1,
        city_name: 1,
      } },
      { $addFields: {
        count: 1,
      } },
      { $match: { area_name: { $exists: true } } },
      ...ctx.helper.getLocationMongo(),
    ];
    return await ctx.model.IviOnlineUserModel.aggregateNGroup(agg);
  }

  async appPlace({ startTime, endTime }) {
    const { ctx } = this;
    return await this.placeApp(ctx.helper.getTimeRangMatch(startTime, endTime, 'login_time'));
  }
  async appLocation({ endTime }) {
    const { ctx } = this;
    // const userArr = await ctx.model.TRbacUserModel.find({
    //   create_date: { $lt: endTime },
    //   user_orgin: 'APP' }, { user_id: 1, _id: 0 }).batchSize(100000);
    const agg = [
      { $match: { login_time: { $lt: endTime }, login_state: 1,
        // user_Id: { $in: userArr.map(item => item.user_id) } } },
      } },
      { $sort: { login_time: 1 } },
      { $group: { _id: '$user_Id',
        provice_name: { $first: '$provice_name' }, city_name: { $first: '$city_name' } } },
      { $lookup: { from: 't_sync_county', localField: 'provice_name', foreignField: 'province_name', as: 'area' } },
      { $project: {
        area_name: { $arrayElemAt: [ '$area.area_name', 0 ] },
        provice_name: 1,
        city_name: 1,
      } },
      { $addFields: {
        count: 1,
      } },
      { $match: { area_name: { $exists: true } } },
      ...ctx.helper.getLocationMongo(),
    ];
    return await ctx.model.AppOnlineUserModel.aggregateNGroup(agg);
  }
  async placeApp(cond) {
    const { ctx } = this;
    const agg = [
      { $match: { ...cond, login_state: 1 } },
      { $sort: { login_time: 1 } },
      { $group: { _id: '$user_Id',
        provice_name: { $first: '$provice_name' }, city_name: { $first: '$city_name' } } },
      { $lookup: { from: 't_sync_county', localField: 'provice_name', foreignField: 'province_name', as: 'area' } },
      { $project: {
        area_name: { $arrayElemAt: [ '$area.area_name', 0 ] },
        provice_name: 1,
        city_name: 1,
      } },
      { $addFields: {
        count: 1,
      } },
      { $match: { area_name: { $exists: true } } },
      ...ctx.helper.getLocationMongo(),
    ];
    return await ctx.model.AppOnlineUserModel.aggregateNGroup(agg);
  }
  async tBoxPlace({ startTime, endTime }) {
    const { ctx } = this;
    const agg = [
      { $match: ctx.helper.getTimeRangMatch(startTime, endTime, 'online_time') },
      { $group: { _id: '$vin' } },
      { $lookup: { from: 't_vehicle_record', localField: '_id', foreignField: 'vin', as: 'car' } },
      { $unwind: { path: '$car', preserveNullAndEmptyArrays: true } },
      { $lookup: { from: 't_sync_province', localField: 'car.pro_code', foreignField: 'out_pro_code', as: 'pro' } },
      { $unwind: '$pro' },
      { $lookup: {
        from: 't_sync_city',
        let: { city_code: '$car.city_code', province_id: '$pro.province_id' },
        pipeline: [{ $match: { $expr: { $and:
                    [
                      { $eq: [ '$out_city_code', '$$city_code' ] },
                      { $eq: [ '$province_id', '$$province_id' ] },
                    ] } } }], as: 'city',
      } },
      { $unwind: '$city' },
      { $lookup: { from: 't_sync_county', localField: 'car.pro_code', foreignField: 'out_pro_code', as: 'area' } },
      { $project: {
        area_name: { $arrayElemAt: [ '$area.area_name', 0 ] },
        provice_name: '$pro.province_name',
        city_name: '$city.city_name',
      } },
      { $addFields: {
        count: 1,
      } },
      { $match: { area_name: { $exists: true } } },
      ...ctx.helper.getLocationMongo(),
    ];
    return await ctx.model.TBoxOnlineModel.aggregateNGroup(agg);
  }

}

module.exports = OnlineUserService2;
